@@ -24,9 +24,17 @@ class AuthResource(RESTResource):
     def _sucessful_login(self, request):
         pass
 
-    def _login(self, user, expiration, form, auth_slug=None):
-        login(self.request, user, expiration, auth_slug, allowed_cookie=self.allowed_cookie,
-              allowed_header=self.allowed_header)
+    def _login(self, user, permanent, form, two_factor_login=False, auth_slug=None):
+        login(
+            self.request,
+            user,
+            auth_slug=auth_slug,
+            preserve_cookie=permanent,
+            allowed_cookie=self.allowed_cookie,
+            allowed_header=self.allowed_header,
+            two_factor_login=two_factor_login,
+            mobile_device=getattr(user, 'authenticated_mobile_device', None)
+        )
 
     def _unsucessful_login(self, request):
         pass
@@ -49,7 +57,7 @@ class AuthResource(RESTResource):
 
         self._sucessful_login(self.request)
         self._login(form.get_user(), not form.is_permanent(), form)
-        return {'token': self.request.token.key, 'user': form.get_user()}
+        return {'token': self.request.token.secret_key, 'user': form.get_user()}
 
     def delete(self):
         if self.request.user.is_authenticated:
